========
Overview
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - |docs|
    * - tests
      - | |build| |requires|
        | |coveralls|
    * - package
      - | |version| |wheel| |supported-versions| |supported-implementations|
        | |commits-since|
.. |docs| image:: https://img.shields.io/badge/docs-GitHub%20Pages-black
    :target: https://allrod5.github.io/pycollect/
    :alt: Documentation Status

.. |build| image:: https://github.com/allrod5/pycollect/workflows/build/badge.svg
    :alt: Build Status
    :target: https://github.com/allrod5/pycollect/actions

.. |requires| image:: https://requires.io/github/allrod5/pycollect/requirements.svg?branch=master
    :alt: Requirements Status
    :target: https://requires.io/github/allrod5/pycollect/requirements/?branch=master

.. |coveralls| image:: https://coveralls.io/repos/allrod5/pycollect/badge.svg?branch=master&service=github
    :alt: Coverage Status
    :target: https://coveralls.io/r/allrod5/pycollect

.. |version| image:: https://img.shields.io/pypi/v/pycollect.svg
    :alt: PyPI Package latest release
    :target: https://pypi.org/project/pycollect

.. |commits-since| image:: https://img.shields.io/github/commits-since/allrod5/pycollect/0.1.1.svg
    :alt: Commits since latest release
    :target: https://github.com/allrod5/pycollect/compare/0.1.1...master

.. |wheel| image:: https://img.shields.io/pypi/wheel/pycollect.svg
    :alt: PyPI Wheel
    :target: https://pypi.org/project/pycollect

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/pycollect.svg
    :alt: Supported versions
    :target: https://pypi.org/project/pycollect

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/pycollect.svg
    :alt: Supported implementations
    :target: https://pypi.org/project/pycollect


.. end-badges

Utility library for collecting valid Python files recursively.

* Free software: MIT license

Installation
============

::

    pip install pycollect


Basic Usage
===========

::

    collector = PythonFileCollector()
    python_files = collector.collect()

Documentation
=============

Complete docs: https://allrod5.github.io/pycollect/


See also
--------

* `CONTRIBUTING <https://allrod5.github.io/pycollect/contributing.html>`_
* `CHANGELOG <https://allrod5.github.io/pycollect/changelog.html>`_
* `AUTHORS <https://allrod5.github.io/pycollect/authors.html>`_
